# GENERATED CODE - DO NOT MODIFY
""""""
from __future__ import annotations
import typing
ReasonType = typing.Literal['com.atproto.moderation.defs#reasonSpam', 'com.atproto.moderation.defs#reasonViolation', 'com.atproto.moderation.defs#reasonMisleading', 'com.atproto.moderation.defs#reasonSexual', 'com.atproto.moderation.defs#reasonRude', 'com.atproto.moderation.defs#reasonOther']
REASON_SPAM = 'com.atproto.moderation.defs#reasonSpam'
REASON_VIOLATION = 'com.atproto.moderation.defs#reasonViolation'
REASON_MISLEADING = 'com.atproto.moderation.defs#reasonMisleading'
REASON_SEXUAL = 'com.atproto.moderation.defs#reasonSexual'
REASON_RUDE = 'com.atproto.moderation.defs#reasonRude'
REASON_OTHER = 'com.atproto.moderation.defs#reasonOther'